@@ -32,7 +32,7 @@ def game(
     name1: str,
     name2: str,
     seed: str = "",
-    return_as_list: bool = True,
+    return_as_list: bool = False,
 ) -> str | list[str]:
     ...
 
@@ -41,7 +41,7 @@ def game(
     name1: str,
     name2: str,
     seed: str = "",
-    return_as_list: bool = True,
+    return_as_list: bool = False,
 ) -> str | list[str]:
     battle_manager = BattleManager(name1, name2, seed)
     result = battle_manager.battle()
@@ -57,7 +57,7 @@ def cli():
     parser = argparse.ArgumentParser()
     parser.add_argument("name1", type=str)
     parser.add_argument("name2", type=str)
-    parser.add_argument("--seed", type=str)
+    parser.add_argument("-s", "--seed", type=str)
     args = parser.parse_args()
 
     result = game(args.name1, args.name2, args.seed, return_as_list=False)
